.nav{display:none}.remote{text-align:center;height:100vh}input{margin:5px 5px 0 5px;width:110px;text-align:right}.lb-buttons{display:grid;grid-template-columns:1fr 1fr;place-items:center;margin-left:10px}.lb-auto,.lb-generate{font-size:1.5em;width:100%}.lb-auto-disabled{color:red}.lb-thumbs-up{font-size:8em}.lb-presets-container,.lb-sequences-container{font-size:25px;margin-top:30px;text-align:center}h1{text-align:center}